@@ -126,8 +126,7 @@ class BackendPasswordFiles(Backend):
             PasswordDirectoryException: Password directory doesn't exist
         """
         settings = {"getpasswd.password_directory": password_directory}
-        super(BackendPasswordFiles, self).__init__(config=config,
-                                                   settings=settings)
+        super().__init__(config=config, settings=settings)
 
     @classmethod
     def parse_arguments(cls, args):
@@ -173,13 +172,13 @@ class BackendPasswordFiles(Backend):
             - Check password_directory exists
         """
         # call parent implementation
-        super(BackendPasswordFiles, self).validate_config()
+        super().validate_config()
         # Check that we got all the necessary information for this backend
         try:
             password_dir = Path(self.config["getpasswd"]["password_directory"])
-        except KeyError:
+        except KeyError as missing_pw_dir:
             raise InvalidConfigurationException(
-                "Missing key: password_directory")
+                "Missing key: password_directory") from missing_pw_dir
 
         if not password_dir.is_dir():
             raise PasswordDirectoryException(
